---
title: <span class="badge object-type-scalar"></span> HertzRotation
---
# <span class="badge object-type-scalar"></span> HertzRotation

Rotational Speed: Hertz (Hz)

## Definition

```python
# Rotational Speed: Hertz (Hz)
HertzRotation: typing.Literal["rothz"] = "rothz"
```
